/**
  *  \file game/simplembox.cc
  *
  *  (c) 2001-2019 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */

#include "game/simplembox.h"

struct GSimpleMailbox::Message {
    string_t heading;
    string_t text;
    Message(const string_t& heading, const string_t& text)
        : heading(heading), text(text)
        { }
};

GSimpleMailbox::GSimpleMailbox()
    : m_messages()
{ }

GSimpleMailbox::~GSimpleMailbox()
{ }

int
GSimpleMailbox::getCount()
{
    return int(m_messages.size());
}

string_t
GSimpleMailbox::getText(int index)
{
    if (size_t(index) < m_messages.size()) {
        return m_messages[index]->heading
            + "\n\n"
            + m_messages[index]->text;
    } else {
        return string_t();
    }
}

string_t
GSimpleMailbox::getHeading(int index)
{
    string_t result;
    if (size_t(index) < m_messages.size()) {
        result = m_messages[index]->heading;
    }

    if (result.size() > 3 && result[0] == '(') {
        while (result.size() > 3 && result[3] != ')') {
            result.erase(3, 1);
        }
    }
    return result;
}

void
GSimpleMailbox::addMessage(string_t heading, string_t text)
{
    m_messages.push_back(new Message(heading, text));
}
